"""
辅助函数
"""

from pathlib import Path# noqa
import matplotlib.pyplot as plt# noqa
import scipy.io as sio# noqa


def save_matrix(matrix, file_name):
    sio.savemat('%s.mat' % file_name, {'matrix': matrix})


def save_fig(matrix, file_name):
    plt.show()
    plt.imsave('%s.jpg' % file_name, matrix)


def make_dir(outdir):
    if not Path(outdir).exists():
        Path(outdir).mkdir(parents=True, exist_ok=True)



from simplelayout.cli.cli_generate import get_options
from simplelayout.generator.core import generate_matrix
from simplelayout.generator.utils import save_fig
from simplelayout.generator.utils import save_matrix
from simplelayout.generator.utils import make_dir


def main():
    option = get_options()
    x = generate_matrix(
        option.board_grid, option.unit_grid, option.unit_n, option.positions)
    make_dir(option.outdir)
    file_path = option.outdir + '/' + option.file_name
    save_matrix(x, file_path)
    save_fig(x, file_path)


if __name__ == "__main__":
    main()



"""
数据生成的主要逻辑
"""


import numpy as np


def generate_matrix(
    board_grid: int, unit_grid: int, unit_n: int, positions: list
) -> np.ndarray:
    x = np.zeros([board_grid, board_grid])
    for i in positions:
        cols = ((i - 1) % int(board_grid / unit_grid)) * unit_grid
        rows = ((i - 1) // int(board_grid / unit_grid)) * unit_grid
        x[rows:rows + unit_grid, cols:cols + unit_grid] = 1
    return x



import pathlib
from setuptools import setup, find_packages
here = pathlib.Path(__file__).parent.resolve()
long_description = (here / "README.md").read_text(encoding="utf-8")
setup(
    name="simplelayout-KomorebiTso",
    version="0.0.1",
    author="KomorebiTso",
    author_email="Komorebi0216@163.com",
    url='https://github.com/idrl-\
        assignment/3-simplelayout-package-KomorebiTso',
    description="simplelayout package",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=find_packages("src"),
    package_dir={'': 'src'},
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        "numpy", "matplotlib", "scipy", "pytest"
    ],
    entry_points={
        'console_scripts': [
            'simplelayout=simplelayout.__main__:main'
        ]
    }
)
